//==================================
//==== SWARM standard library ======
//==================================



//----------------------------------
//--- Default variable settings ----
//==================================

$CenterPoint		= "MissionGroup\\CenterPoint";
$NewDropDistance 	= "";
$NewDropPoint 		= "MissionGroup\\DropPointGroup1\\DropPoint";
$Siren			= "sfx_siren.wav";
$ammoTriggerReady	= true;
$chokeValue		= 0;
$dropRadius 		= 300;
$healTriggerReady	= true;
$marker			= "MissionGroup\\marker1";
$minDropSeparation	= "";
$newDropX 		= "0";
$newDropY 		= "0";
$newDropZ 		= "200";
$oldDropX 		= "";
$oldDropY 		= "";
$sackValue		= 1;
$snuffValue   		= 2;
$spawningPlayer		= "2049";
$spawningVehicle	= "";
$sqrdDistance 		= "";
$tagWon			= 0;
$warningBuffer		= 250;
$warningDistance	= 750;
$winScore		= 150;
$xRangeMinus 		= "";
$xRangePlus 		= "";
$xdist 			= "";
$yRangeMinus 		= "";
$yRangePlus 		= "";
$ydist 			= "";
$beam			= "MissionGroup\\Beam";


//----------------------------------
//--- Server Log Functions ----
//==================================

function player::onAddLog(%this)
{
   missionLog(getName(%this), " (", %this, ", ", getConnection(%this), ") joined [",$server::Hostname,"]");
}      

//--------------------------------------
function player::onRemoveLog(%this) 
{
   missionLog(getName(%this), " (", %this, ", ", getConnection(%this), ") left [",$server::Hostname,"]");
}

//----------------------------------
//--- Startup Functions ----
//==================================

function setDefaultMissionOptions()
{
   $server::AllowTeamRed = false;
   $server::AllowTeamBlue = true;
   $server::AllowTeamYellow = false;
   $server::AllowTeamPurple = true;

   $server::TeamPlay = true;
   $server::AllowDeathmatch = false;
   $server::AllowTeamPlay = true;	
   $server::TeamDamage = true; 
   initWarnCount();
}

function onMissionStart(%playerNum)
{

	setKillValues();
	displayKillValues(%playerNum);

	//reinitialize scores of players who were in previous game
	
	%count = playerManager::getPlayerCount();
	for(%i = 0; %i < %count; %i = %i + 1)
	{
		%curPlayerNum = playerManager::getPlayerNum(%i);
		initStats(%curPlayerNum);
	}

	//Make first person to enter sim IT
	
	dataStore(0, strcat(%playerNum, "isIt"), "Yes");
	say(%playerNum,0, strcat(getName(%playerNum), " is now IT!"));
	boundryCheck();
	
}	

//============================	
//--------MOVE THE MAP--------
//============================	
// Don't forget to move the overhead map.  This should be defined in
// the map script where centerX and CenterY are the values
//$server::HudMapViewOffsetX = 161.497;
//$server::HudMapViewOffsetY = 460.577;

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// SWARM Game Info Tags
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
function setRules()
{
      %rules = "<F2>GAME TYPE: \n<F0>SWARM\n\n"@        
               "<F2>MISSION: \n<F0>" @
               $missionName @
               "\n\n<F2>SYNOPSIS:\n"@
               "<F0>A game of tag. Each Player targets the person who is IT. "@
               "When you kill IT, you are awarded points for the kill. "@
               "When you are IT, you are awarded even higher points for kills. "@
               "IT will be glowing PURPLE."@
               "\n\n<F2>RULES/OBJECTIVES:\n"@
               "<F0>1) KILL IT!\n"@
               "2) Kill as many vehicles as possible while you are IT.\n\n"@
               "<F2>SCORING:\n"@
               "<F0>Killing IT is called a SACK and is worth<F3>"@
               $sackValue @
               " <F0>point(s).\n\n"@
               "Killing other while you are IT is a SNUFF and is worth <F3>"@
               $snuffValue @
               " <F0>point(s).\n\n"@
               "<F3>NOTE: Being killed by IT is called a CHOKE and will lose you \n\n"@
               $chokeValue @
               " <F0>point(s).\n\n"@
               "<F6>SCORING ADJUSTMENTS:\n"@
               "\n"@
               "<F0># of players\t\t<F2>SNUFF\t<F5>SACK  <F3>CHOKE\n"@
               "<F0> 2 or less\t\t\t<F2>2pts\t\t<F5>1pt\t\t<F3>0pts\n"@
               "<F0> 3 players\t\t\t<F2>3pts\t\t<F5>1pt\t\t<F3>0pts\n"@
               "<F0> 4 players\t\t\t<F2>4pts\t\t<F5>2pts\t\t<F3>-1pts\n"@
               "<F0> 5 players\t\t\t<F2>6pts\t\t<F5>3pts\t\t<F3>-2pts\n"@
               "<F0> 6 players\t\t\t<F2>8pts\t\t<F5>4pts\t\t<F3>-2pts\n"@
               "<F0> 7 or more\t\t<F2>10pts\t\t<F5>4pts\t\t<F3>-4pts\n";


   setGameInfo(%rules);      
   }




// setup the rules
// this has to be called after the definition of setRules
setRules();
	
//----------------------------------
//--- ADD/REMOVE Functions ---------
//==================================
function player::onAdd(%playerNum)
{
   	$missionObject = getObjectId(MissionGroup);
  	setKillValues();
  	displayKillValues(%playerNum);
   	initStats(%playerNum);
   	say(%playerNum,0, strcat("Welcome to Starsiege SWARM, ", getName(%playerNum), ". Here are the rules: "));
   	say(%playerNum,0, strcat("- You get " , $sackValue, " point(s) for SACKING 'IT'."));
   	say(%playerNum,0, strcat("- You get ", $snuffValue, " points for SNUFFING someone while you are 'IT'."));
   	say(%playerNum,0, strcat("- You CHOKE if 'IT' kills you and you lose ", $chokeValue, " point(s)."));
   	say(%playerNum,0, "- You become 'IT' by sacking 'IT'.");
   	say(%playerNum,0, strcat("- The first player to reach ", $winScore, " points wins the game."));
   	$missionObject.playerNum = %this;
   
}

//-------------------------------------------------------------
function player::onRemove(%playerNum)
{
  	setKillValues();
	displayKillValues(%playerNum);
  	
  	
  	if(%playerNum == getItNum())
   	{
	 	%newItNum = getHighScorePlayerNum(%playerNum);

	   	if(%newItNum != "" && %newItNum != 0)
		{
		  	dataStore(0, strcat(%newItNum, "isIt"), "Yes" );
		  	say(0,0, strcat(getName(%newItNum), " is now IT!"));
			
			%vehicleId = playerManager::playerNumToVehicleId(%newItNum);
			setTeam(%vehicleId, *IDSTR_TEAM_PURPLE);
			setVehicleSpecialIdentity(%vehicleId, true, *IDSTR_TEAM_PURPLE);

			resetAmmoTrigger(%newItNum);
			resetHealTrigger(%newItNum);
	   	}
	}
	
	cleanUp(%playerNum);
	
	
}

//-------------------------------------------------------------
function vehicle::onAdd(%vehicleId)
{
	setTeam(%vehicleId, *IDSTR_TEAM_BLUE);
	%playerNum = playerManager::vehicleIdToPlayerNum(%vehicleId);
//	setVehicleSpecialIdentity(%vehicleId, true, *IDSTR_TEAM_BLUE);
	
	//if no one is IT, make this person IT
	if(getItNum() == false)
	{
		%playerNum = playerManager::vehicleIdToPlayerNum(%vehicleId);
		
		dataStore(0, strcat(%playerNum, "isIt"), "Yes" );
		say(%playerNum,0, strcat(getName(%playerNum), " is now IT!"));
	}
	
   	if(playerManager::vehicleIdToPlayerNum(%vehicleId) == getItNum())
	{
		setTeam(%vehicleId, *IDSTR_TEAM_PURPLE);
		setVehicleSpecialIdentity(%vehicleId, true, *IDSTR_TEAM_PURPLE);
	}

   	%num = playerManager::vehicleIdToPlayerNum(%vehicleId);
   	$playerDrop = %num;
   	if(%num == $missionObject.playerNum)
   		{
      		$missionObject.playerId = playerManager::playerNumToVehicleId($missionObject.playerNum);
   		}
	$spawningPlayer  = %playerNum;
	$spawningVehicle = %vehicleId;
   	displayKillValues();  
	getDropCoord();
}

//----------------------------------
//--- onDestroyed Functions --------
//==================================

function vehicle::onDestroyed(%destroyedId, %destroyerId)
{
	%destroyerNum = playerManager::vehicleIdToPlayerNum(%destroyerId);
	%destroyedNum = playerManager::vehicleIdToPlayerNum(%destroyedId);  	
	
	if($tagWon == 1)
	{
		return;
	}
		
	if(itKilledSelf(%destroyedNum, %destroyerNum))
	{
		return;
	}
	
	if(itKilledPlayer(%destroyedNum, %destroyerNum))
	{
		return;
	}
	
	if(playerKilledIt(%destroyedNum, %destroyerNum))
	{
		
	    setTeam(%destroyerId, *IDSTR_TEAM_PURPLE);
	    
	    setVehicleSpecialIdentity(%destroyedId, false);
		setVehicleSpecialIdentity(%destroyerId, true, *IDSTR_TEAM_PURPLE);
		return;
	}
	
//	 if we got here, a not-it player must have killed another not-it player
//	 which is ignored
}

//--------------------------------------------------------
function itKilledSelf(%destroyedNum, %destroyerNum)
{
	// if there is only one player, keep that player IT
	
	if(playerManager::getPlayerCount() == 1)
   	{
		return true;
	}


	if(%destroyerNum == getItNum() && %destroyedNum == getItNum())
	{
		%newItNum = getHighScorePlayerNum(%playerNum);
		
	   	if(%newItNum != "" && %newItNum != 0)
		{
		  	dataStore(0, strcat(%destroyedNum, "isIt"), "No" );
		  	dataStore(0, strcat(%newItNum, "isIt"), "Yes" );
		  	
		  	say(0,0, strcat(getName(%newItNum), " is now IT!"));

			%vehicleId = playerManager::playerNumToVehicleId(%newItNum);
			
			setTeam(%vehicleId, *IDSTR_TEAM_PURPLE);
			setVehicleSpecialIdentity(%vehicleId, true, *IDSTR_TEAM_PURPLE);
		
			resetAmmoTrigger(%newItNum);
			resetHealTrigger(%newItNum);
	   	}

		return true;
	}
	return false;
}

//---------------------------------------------------------
function itKilledPlayer(%destroyedNum, %destroyerNum)
{
	
	if(%destroyerNum == getItNum())
	{
		%snuffKey	= strcat(%destroyerNum, "snuff");
		%chokeKey 	= strcat(%destroyedNum, "choke");
		
		dataStore(0, %snuffKey, 1 + dataRetrieve(0, %snuffKey));
		dataStore(0, %chokeKey, 1 + dataRetrieve(0, %chokeKey));

		if(playerWonGame(%destroyerNum))
		{
			return true;
		}
		
		else
		{
			say(0,0, strcat(getName(%destroyedNum), " was Snuffed by IT! "));
			%object = playerManager::playerNumToVehicleId(%destroyedNum);
			say(%object, 0, strcat(getName(%destroyedNum), " you CHOKED!"));
		}
		return true;
	}
	return false;
}

//-------------------------------------------------------
function playerKilledIt(%destroyedNum, %destroyerNum)
{
	
	if(%destroyedNum == getItNum())
	{	
		%newItKey = strcat(%destroyerNum, "isIt");
		%oldItKey = strcat(%destroyedNum, "isIt");
		%sackKey  = strcat(%destroyerNum, "sack");

		dataStore(0, %oldItKey, "No");
		dataStore(0, %newItkey, "Yes");
		dataStore(0, %sackKey, 1 + dataRetrieve(0, %sackKey));
		
		if(playerWonGame(%destroyerNum))
		{
			return true;
		}
		
		else
		{	
			say(0,0, strcat(getName(%destroyerNum), " Sacked IT!"));
		  	say(0,0, strcat(getName(%destroyerNum), " is now IT!"));
		  	//say(%destroyerNum,0,"sfx_siren.wav");
		  	%x = getPosition("MissionGroup/CenterPoint", "x");
			%y = getPosition("MissionGroup/CenterPoint", "y");
			%z = getTerrainHeight(%x, %y) + 100;
		  	say(%destroyerNum, 0, "sfx_siren.wav");
		}
		
		resetAmmoTrigger(%destroyerNum);
		resetHealTrigger(%destroyerNum);

		
		return true;
	}
	return false;
}

//----------------------------------
//--- Functions for finding IT  ----
//==================================

function getItNum()
{
	%count = playerManager::getPlayerCount();
	for(%i = 0; %i < %count; %i = %i + 1)
	{
		%curPlayerNum = playerManager::getPlayerNum(%i);
		if(dataRetrieve(0, strcat(%curPlayerNum, "isIt")) == "Yes")
		{
			return %curPlayerNum;
		}	
	}
	//return false if no one is IT
	return false;
}

//--------------------------------------------------------
function getHighScorePlayerNum(%playerNum)
{
	%highScore = 0;
	%count = playerManager::getPlayerCount();
	%highScorePlayerNum = "";
	
	for(%i = 0; %i < %count; %i = %i + 1)
	{
		%curPlayerNum = playerManager::getPlayerNum(%i);
		%score = getPlayerScore(%curPlayerNum);
		if(%curPlayerNum != %playerNum && %score >= %highScore)
		{
			%highScore = %score;
			%highScorePlayerNum = %curPlayerNum;
		}
	}
	
	return %highScorePlayerNum;	
}

//--------------------------------------
//-Initialization / GameEnd Functions --
//======================================

function initStats(%playerNum)
{
	dataStore(0, strcat(%playerNum, "snuff"), 0 );
	dataStore(0, strcat(%playerNum, "choke"),0);
	dataStore(0, strcat(%playerNum, "sack"),0);
	dataStore(0, strcat(%playerNum, "isIt"),"No");
}

//-------------------------------------------------------
function playerWonGame(%playerNum)
{
	if(getPlayerScore(%playerNum) >= $winScore)
	{
		$tagWon = 1;
		
		messagebox(0,"GAME OVER\n\n" @getName(%playerNum)@" won the Game!"); 
		
		%missionEnd = strcat(getName(%playerNum), " won the Game!");
		messageBox(0, %missionEnd);

		%orderFade = "fadeEvent(0, out, 5, 0,0,0 );";
		schedule(%orderFade, 5.0);
		
		schedule("missionEndConditionMet();", 10.0);

		return true;
	}
	return false;
} 

//--------------------------------------------------------
function cleanUp(%playerNum)
{
	dataRelease(0, strcat(%playerNum, "snuff"));
	dataRelease(0, strcat(%playerNum, "choke"));
	dataRelease(0, strcat(%playerNum, "sack"));
	dataRelease(0, strcat(%playerNum, "isIt"));
}

//-------------------------------
//------ SWARM SCOREBOARD -------
//===============================

function getPlayerScore(%a)
{
	return (getPlayerSnuffs(%a) * $snuffValue + getPlayerSacks(%a) * $sackValue - getPlayerChokes(%a) * $chokeValue); // - getPlayerFriendlyKills(%a) * $friendlyKillValue);
}

function getPlayerSnuffs(%playerNum)
{
	return dataRetrieve(0, strcat(%playerNum, "snuff"));
}

function getPlayerSacks(%playerNum)
{
	return dataRetrieve(0, strcat(%playerNum, "sack"));	
}

function getPlayerItStatus(%playerNum)
{
	return dataRetrieve(0, strcat(%playerNum, "isIt"));

}

function getPlayerChokes(%playerNum)
{
	return dataRetrieve(0, strcat(%playerNum, "choke"));
}

//----------------------------------------------
function initScoreboard()
{
   deleteVariables("$ScoreBoard::PlayerColumn*");
   deleteVariables("$ScoreBoard::TeamColumn*");

   // Player ScoreBoard column headings
   $ScoreBoard::PlayerColumnHeader1 = "SCORE";
   $ScoreBoard::PlayerColumnHeader2 = "IT";
   $ScoreBoard::PlayerColumnHeader3 = "SNUFFS";
   $ScoreBoard::PlayerColumnHeader4 = "SACKS";
   $ScoreBoard::PlayerColumnHeader5 = "CHOKES";
   $ScoreBoard::PlayerColumnHeader5 = "PING";
   
   //Player ScoreBoard column functions
   $ScoreBoard::PlayerColumnFunction1 = "getPlayerScore";
   $ScoreBoard::PlayerColumnFunction2 = "getPlayerItStatus";
   $ScoreBoard::PlayerColumnFunction3 = "getPlayerSnuffs";
   $ScoreBoard::PlayerColumnFunction4 = "getPlayerSacks";
   $ScoreBoard::PlayerColumnFunction5 = "getPlayerChokes";
   $ScoreBoard::PlayerColumnFunction5 = "getPing";

   // tell server to process all the scoreboard definitions defined above
   serverInitScoreBoard();
	
}


//----------------------------------
//---------- TRIGGERS! -------------
//==================================

function heal::trigger::onEnter(%this, %object)
{
	%playerNum = playerManager::vehicleIdToPlayerNum(%object);
	
	//playSound(%object, IDCV_POWER_ON);
	//say(%playerNum, 0, "Entering repair area.");
	
	if(%playerNum == getItNum() && $healTriggerReady == true)
	{	
		healObject(%object, 10000.0);
		healObject(%object, 10000.0);
		healObject(%object, 10000.0);
		say(%playerNum,0,"cy_Repairs_complete.WAV");
		$healTriggerReady = false;
		
		initResetHealTimer(%playerNum);
		
	}
	
	else
	{
	   say(%playerNum, 0, *IDMULT_CHAT_HEALPAD);  
	   say(%playerNum, 0, "cy_Repair_ent.WAV");
	}
}

function heal::trigger::onContact(%this, %object)
{					  
   	//echo("onContact_trigger = ", %this, " ", %object);
   	
   	if(isShutdown(%object) == true)
   	{
   		healObject(%object, 200.0);
   	//	say(%playerNum,0,"Repairs_complete.WAV");
	}
}



//--------------------------------------
function reload::trigger::onEnter(%this, %object)
{
    %playerNum = playerManager::vehicleIdToPlayerNum(%object);
	
	//playSound(%object, IDCV_POWER_ON);
	//say(%playerNum, 0, "Entering reload area.");
	
	if(%playerNum == getItNum() && $ammoTriggerReady == true)
	{	
		reloadObject(%object, 100.0);
		say(%playerNum,0,"cy_reload_complete.WAV");
		$ammoTriggerReady = false;
		
		initResetAmmoTimer(%playerNum);

	}
	
	else
	
	{
	   say(%playerNum, 0, *IDMULT_CHAT_AMMOPAD);  
	   say(%playerNum, 0, "cy_reload_ent.wav");
	}
}

function reload::trigger::onContact(%this, %object)
{
   	//echo("onContact_trigger = ", %this, " ", %object);
   	
   	if(isShutdown(%object) == true)
   	{
   		reloadObject(%object, 100.0);
   	//	say(%playerNum,0,"reload_complete.WAV");
	}
}




//----------------------------------
//----------- TIMERS ---------------
//==================================
function initResetHealTimer(%playerNum)
{
	%playerCount = playerManager::getPlayerCount();
	%timer = 35 - ((%playerCount - 1) * 5);

	if( %timer < 20)
	{	
		%timer = 20;
	}

	%order = strcat("resetHealTrigger(", %playerNum, ");");
	schedule (%order, %timer);
}

//-----------------------------------------------
function initResetAmmoTimer(%playerNum)
{
	%playerCount = playerManager::getPlayerCount();
	%timer = 35 - ((%playerCount - 1) * 5);

	if( %timer < 20)
	{	
		%timer = 20;
	}

	%order = strcat("resetAmmoTrigger(", %playerNum, ");");
	schedule (%order, %timer);
}
	
//---------------------------------------------
function resetAmmoTrigger(%playerNum)
{
	%object = playerManager::playerNumToVehicleId(%playerNum);

	
	if (%playerNum == getItNum())
	{
		$ammoTriggerReady = true;
		say(%playerNum, 0, "<F5>RELOAD PAD IS READY!<F3>");
		say(%playerNum, 0, "teleporter.wav");
	}
}
		
//---------------------------------------------
function resetHealTrigger(%playerNum)
{
	%object = playerManager::playerNumToVehicleId(%playerNum);

	if (%playerNum == getItNum())
	{
		$healTriggerReady = true;
		say(%playerNum, 0, "<F5>HEAL PAD IS READY!<F3>");
		say(%playerNum, 0, "Bigflyby.wav");
	}
}

//----------------------------------
//---- VARIABLE KILL VALUES --------
//==================================

function setKillValues()
{	
	%playerCount = playerManager::getPlayerCount();

	if(%playerCount <= 2)
	{
		$snuffValue = 2;
		$sackValue 	= 1;
		$chokeValue = 0;
		return;
	}
	
   	if(%playerCount == 3)
	{
		$snuffValue = 3;
		$sackValue 	= 1;
		$chokeValue = 0;
		return;
	}
	
	if(%playerCount == 4)
	{
		$snuffValue = 4;
		$sackValue 	= 2;
		$chokeValue = 1;
		return;
	}
	
	if(%playerCount == 5)
	{
		$snuffValue = 6;
		$sackValue 	= 3;
		$chokeValue = 2;
		return;
	}
	
	if(%playerCount == 6)
	{
		$snuffValue = 8;
		$sackValue 	= 4;
		$chokeValue = 2;
		return;
	}
	
	if(%playerCount >= 7)
	{
		$snuffValue = 10;
		$sackValue 	= 4;
		$chokeValue = 2;
		return;
	}					
	
	return;
}

//----------------------------------
//--------- POINT UPDATE -----------
//==================================

function displayKillValues(%playerNum)
{	
	%tempITnum = getitnum();
	say($spawningPlayer,0, strcat("POINT UPDATE: SNUFF = ", $snuffValue, " | SACK = ", $sackValue, " | CHOKE = ", $chokeValue));	
	say($spawningPlayer,0, strcat(getName(%tempITnum), " is now IT!"));
}

//----------------------------------
//----- CHECK FOR RUNAWAYS ---------
//==================================

function initWarnCount()
	{
	$warnCount = 0;
	}

function boundryCheck(%player)
{
	%itNum = getItNum();
	%itName = getName(%itNum);
	%itVehicle = playerManager::playerNumToVehicleId(%itNum);
	%killIfLeft = %itVehicle;

	%distance = getDistance("MissionGroup/CenterPoint", %itVehicle);
	
	if ( %distance >= $warningDistance )
	{
		if ( %distance < ($warningDistance + $warningBuffer))
			{
			if ($warnCount == 5.0)
				{
				%distance = 2000;
				initWarnCount();
				}
			
			else
				{
				say(%itNum,0,"CY_boundary.WAV");
				$warnCount = ($warnCount + 1.0);
				}
			}
	}
	
	if ( %distance >= ($warningDistance + $warningBuffer) )
	{	
		say(0,0, strcat(%itName, " has run away!"));
		say(%itNum,0, strcat("Say goodbye to your score and your life ", %itName, "!"));
		say(%itNum,0,"TR_OUTR01.WAV");
		damageObject(%itVehicle, 50000 );		
		
		// remove sacks and snuffs but keep chokes
		
		%snuffKey	= strcat(%itNum, "snuff");
		%itKey 		= strcat(%itNum, "isIt");
		%sackKey  	= strcat(%itNum, "sack");

		dataStore(0, %snuffKey, 0);
		dataStore(0, %itKey, "No");
		dataStore(0, %sackKey, 0);

		// select new It

		%newItNum = getHighScorePlayerNum(%playerNum);

	}

	%order = "boundryCheck();";
	schedule(%order, 10.0);

}


//----------------------------------
//--- RANDOMIZE DROP POINTS --------
//==================================

function getDropCoord(%playerNum)
{
	$oldDropX 	= getPosition($CenterPoint, "x");
	$oldDropY 	= getPosition($CenterPoint, "y");
	$xRangePlus 	= ($oldDropX + $dropRadius);
	$xRangeMinus 	= ($oldDropX - $dropRadius);
	$yRangePlus 	= ($oldDropY + $dropRadius);
	$yRangeMinus 	= ($oldDropY - $dropRadius);
	$newDropX 	= randomInt($xRangeMinus, $xRangePlus);
	$newDropY 	= randomInt($yRangeMinus, $yRangePlus);
	$newDropZ 	= getTerrainHeight($newDropX, $newDropY) + 100;
	$newDropR	= randomInt(1,360);
	$spawningX 	= getPosition($spawningVehicle, "x");
	$spawningY 	= getPosition($spawningVehicle, "y");	
	setPosition($marker, $newDropX, $newDropY, $newDropZ);
	measureNewDist(%playerNum);
}

function measureNewDist(%playerNum)
{
	$NewDropDistance = getDistance($marker, $newDropPoint);
	CheckCenter();
}

function checkCenter()
	{
	say(0,0,"checkCenter()");
	$DistFromCenter = getDistance($marker, $CenterPoint);
	if ($DistFromCenter <= $dropRadius)
		{
		checkSpawn();
		}
	else
		{
		schedule("getDropCoord();",0.05);
		return;
		}
	}

function checkOldDist()
	{
	say(0,0,"checkOldDist()");
		$NewDropDistance = getDistance($marker, $newDropPoint);
	if ($NewDropDistance >= $dropRadius)
		{
		CheckSpawn();
		}
	else
		{
		schedule("getDropCoord();",0.05);
		return;
		}
	}

function checkSpawn()
	{
	say(0,0,"checkSpawn()");
	$DistFromLastSpawn = getDistance($marker, $SpawningVehicle);
	if ($DistFromLastSpawn >= ($dropRadius/2))
		{
		CheckForObjects();
		}
	else
		{
		schedule("getDropCoord();",0.05);
		return;
		}
	}


function CheckForObjects()
	{
	
	for(%i = 8195; %i < 8250; %i = %i + 1)
		{
		%objectvicinity = (getDistance(%i, $marker)/3);
		//say(0,0,"checkForObjects() "@%i@" is "@%objectvicinity);
		
		if (%objectvicinity == 0) 
			{
			}
		else
		
		if (%objectvicinity <= 40 )
			{
			schedule("getDropCoord();",0.05);
			return;
			}
		}
	setPosition($NewDropPoint, $newDropX, $newDropY, $newDropZ);
	}
	
function moveit()
	{
	getDropCoord();
	}